@@ -1,14 +1,13 @@
 ### Modified from Rserve/src/install.libs.R
 ### For libs
-files <- c("pbdNCDF4.so", "pbdNCDF4.so.dSYM", "pbdNCDF4.dylib", "pbdNCDF4.dll")
+files <- c("pbdNCDF4.so", "pbdNCDF4.so.dSYM", "pbdNCDF4.dylib", "pbdNCDF4.dll",
+           "symbols.rds")
 files <- files[file.exists(files)]
 if(length(files) > 0){
   libsarch <- if (nzchar(R_ARCH)) paste("libs", R_ARCH, sep='') else "libs"
   dest <- file.path(R_PACKAGE_DIR, libsarch)
   dir.create(dest, recursive = TRUE, showWarnings = FALSE)
   file.copy(files, dest, overwrite = TRUE, recursive = TRUE)
-  if(file.exists("symbols.rds"))
-    file.copy("symbols.rds", dest, overwrite = TRUE)
 }
 ### For etc
 file <- "Makeconf"
